@@ -3,7 +3,7 @@ package WWW::FreeProxyListsCom;
 use warnings;
 use strict;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 use Carp;
 use URI;
@@ -23,8 +23,13 @@ __PACKAGE__->mk_group_accessors( simple => qw/
 
 sub new {
     my $self = bless {}, shift;
-    get_args_as_hash(\@_, \my %args, { timeout => 30 } )
-        or croak $@;
+
+    get_args_as_hash(
+        \@_, \my %args,
+        {
+            timeout => 30,
+        }
+    ) or croak $@;
 
     $args{mech} ||= WWW::Mechanize->new(
         timeout => $args{timeout},
@@ -37,7 +42,6 @@ sub new {
 
     return $self;
 }
-
 sub get_list {
     my $self = shift;
 
@@ -52,12 +56,15 @@ sub get_list {
     my %page_for = (
         non_anonymous   => 'non-anonymous',
         map { $_ => $_ } qw(
-            elite
-            anonymous
-            https
-            standard
-            us
-            socks
+                elite
+                anonymous
+                https
+                standard
+                socks
+                us
+                uk
+                ca
+                fr
         ),
     );
 
@@ -67,12 +74,14 @@ sub get_list {
 
     my $mech = $self->mech;
     my $page_type = $page_for{ $args{type} };
+    my $url = $self->_url;
+
     my $uri = URI->new(
-        "http://www.freeproxylists.com/$page_type.html"
+        "$url/$page_type.html"
     );
 
     $mech->get($uri)->is_success
-        or return $self->_set_error($mech,'net');
+        or return $self->_set_error($mech, 'net');
 
     $page_type eq 'anonymous'
         and $page_type = 'anon';
@@ -107,7 +116,6 @@ sub get_list {
 
     return $self->list( \@proxies );
 }
-
 sub filter {
     my $self = shift;
 
@@ -150,8 +158,6 @@ sub filter {
     }
     return $self->filtered_list( \@filtered );
 }
-
-
 sub _parse_list {
     my ( $self, $content ) = @_;
 
@@ -196,7 +202,6 @@ sub _parse_list {
     shift @data; # quick and dirty fix to rid of bad data.
     return \@data;
 }
-
 sub _set_error {
     my ( $self, $mech_or_error, $type ) = @_;
     if ( defined $type and $type eq 'net' ) {
@@ -207,7 +212,11 @@ sub _set_error {
     }
     return;
 }
-
+sub _url {
+    my ($self, $url) = @_;
+    $self->{url} = $url if defined $url;
+    return defined $self->{url} ? $self->{url} : 'http://freeproxylists.com';
+}
 1;
 __END__
 
@@ -317,18 +326,20 @@ as follows:
 
     ->get_list( type => 'standard' );
 
-B<Optional>. Specifies the list of proxies to fetch. B<Defaults to:>
-C<elite>. Possible arguments are
-as follows (valid C<type> values are on the left, corresponding "list" site's
-menu link names are on the right):
+B<Optional>. Specifies the list of proxies to fetch. B<Defaults to:> C<elite>.
+Possible arguments are as follows. Note all are plain HTTP except C<socks> and
+C<https>.
 
-    elite           => http elite proxies
-    anonymous       => http anonymous lists
-    non_anonymous   => http non-anonymous
-    https           => https (SSL enabled)
-    standard        => http standard ports
-    us              => us proxies only
-    socks           => socks (version 4/5)
+    elite           = Elite (hides you entirely)
+    anonymous       = Anonymous (hides you, but shows you're using a proxy)
+    non_anonymous   = non-anonymous (no masking at all)
+    https           = HTTPS (SSL enabled, may not hide you)
+    standard        = standard HTTP/HTTPS/SOCKS/Proxy ports (may not hide you)
+    ca              = Canada
+    fr              = France
+    us              = United States
+    uk              = United Kingdom
+    socks           = SOCKS (version 4/5)
 
 =head3 C<max_pages>
 
